@@ -4,11 +4,12 @@
  * SPDX-License-Identifier: LGPL-2.0-or-later
  */
 #pragma once
+
 #include "alertentry.h"
-#include "kweathercore/kweathercore_export.h"
-#include <QObject>
-#include <memory>
+#include "reply.h"
+
 class QNetworkReply;
+
 namespace KWeatherCore
 {
 class PendingCAPPrivate;
@@ -20,36 +21,22 @@ class PendingCAPPrivate;
  *
  * @author Han Young <hanyoung@protonmail.com>
  */
-class KWEATHERCORE_EXPORT PendingCAP : public QObject
+class KWEATHERCORE_EXPORT PendingCAP : public Reply
 {
     Q_OBJECT
 public:
+    ~PendingCAP();
+
     /**
      * value pointer to the shared alerts data
      * the pointer is nullptr until finished() raised
      * @return
      */
     std::unique_ptr<AlertEntry> value() const;
-    /**
-     * isFinished if the call has finished
-     * @return
-     */
-    bool isFinished() const;
-Q_SIGNALS:
-    /**
-     * signals the call has finished
-     */
-    void finished();
-    /**
-     * indicate there is a network error
-     */
-    void networkError();
-
-protected:
-    friend class AlertFeedEntry;
-    explicit PendingCAP(QNetworkReply *reply = nullptr);
 
 private:
-    PendingCAPPrivate *d = nullptr;
+    friend class AlertFeedEntry;
+    explicit PendingCAP(QNetworkReply *reply, QObject *parent = nullptr);
+    Q_DECLARE_PRIVATE(PendingCAP)
 };
 }
