@@ -4,70 +4,42 @@
  *
  * SPDX-License-Identifier: LGPL-2.0-or-later
  */
+
 #include "pendingweatherforecast.h"
 #include "geotimezone.h"
 #include "kweathercore_p.h"
+#include "kweathercore_version.h"
 #include "pendingweatherforecast_p.h"
 #include "sunrisesource.h"
-#include <KLocalizedString>
+
+#include <KHolidays/SunRiseSet>
+
 #include <QDir>
 #include <QFile>
 #include <QJsonArray>
 #include <QJsonDocument>
 #include <QJsonObject>
+#include <QNetworkAccessManager>
 #include <QNetworkReply>
 #include <QStandardPaths>
 #include <QTimeZone>
+#include <QUrlQuery>
+
 namespace KWeatherCore
 {
-PendingWeatherForecastPrivate::PendingWeatherForecastPrivate(double latitude,
-                                                             double longitude,
-                                                             const QString &timezone,
-                                                             const QUrl &url,
-                                                             const std::vector<Sunrise> &sunrise,
-                                                             PendingWeatherForecast *parent)
-    : QObject(parent)
-    , m_latitude(latitude)
-    , m_longitude(longitude)
-    , m_timezone(timezone)
-{
-    connect(this, &PendingWeatherForecastPrivate::finished, [this] {
-        this->isFinished = true;
-    });
-    connect(this, &PendingWeatherForecastPrivate::finished, parent, &PendingWeatherForecast::finished);
-    connect(this, &PendingWeatherForecastPrivate::networkError, parent, &PendingWeatherForecast::networkError);
 
-    QNetworkRequest req(url);
-    req.setAttribute(QNetworkRequest::RedirectPolicyAttribute, QNetworkRequest::NoLessSafeRedirectPolicy);
-
-    // see §Identification on https://api.met.no/conditions_service.html
-    req.setHeader(QNetworkRequest::UserAgentHeader,
-                  QString(QStringLiteral("KWeatherCore/") + VERSION_NUMBER + QStringLiteral(" kde-frameworks-devel@kde.org")));
-    connect(&m_manager, &QNetworkAccessManager::finished, this, &PendingWeatherForecastPrivate::parseWeatherForecastResults);
-    m_manager.get(req);
-
-    forecast.setCoordinate(latitude, longitude);
-
-    m_sunriseSource = new SunriseSource(latitude, longitude, m_timezone, sunrise, this);
-    if (timezone.isEmpty()) {
-        hasTimezone = false;
-        getTimezone(latitude, longitude);
-    } else {
-        hasTimezone = true;
-        forecast.setTimezone(timezone);
-        m_timezone = timezone;
-        getSunrise();
-    }
-}
-PendingWeatherForecastPrivate::PendingWeatherForecastPrivate(WeatherForecast data)
-    : forecast(data)
-    , isFinished(true)
+PendingWeatherForecastPrivate::PendingWeatherForecastPrivate(PendingWeatherForecast *qq)
+    : q(qq)
 {
 }
+
 void PendingWeatherForecastPrivate::getTimezone(double latitude, double longitude)
 {
-    auto timezoneSource = new GeoTimezone(latitude, longitude, this);
-    connect(timezoneSource, &GeoTimezone::finished, this, &PendingWeatherForecastPrivate::parseTimezoneResult);
+    auto timezoneSource = new GeoTimezone(m_manager, latitude, longitude, q);
+    QObject::connect(timezoneSource, &GeoTimezone::finished, q, [this, timezoneSource]() {
+        timezoneSource->deleteLater();
+        parseTimezoneResult(timezoneSource->timezone());
+    });
 }
 void PendingWeatherForecastPrivate::parseTimezoneResult(const QString &result)
 {
@@ -79,7 +51,9 @@ void PendingWeatherForecastPrivate::parseTimezoneResult(const QString &result)
 
 void PendingWeatherForecastPrivate::getSunrise()
 {
-    connect(m_sunriseSource, &SunriseSource::finished, this, &PendingWeatherForecastPrivate::parseSunriseResults);
+    QObject::connect(m_sunriseSource, &SunriseSource::finished, q, [this]() {
+        parseSunriseResults();
+    });
     m_sunriseSource->setTimezone(m_timezone);
     m_sunriseSource->requestData();
 }
@@ -95,9 +69,10 @@ void PendingWeatherForecastPrivate::parseSunriseResults()
 void PendingWeatherForecastPrivate::parseWeatherForecastResults(QNetworkReply *reply)
 {
     reply->deleteLater();
-    if (reply->error()) {
+    if (reply->error() != QNetworkReply::NoError) {
         qWarning() << "network error when fetching forecast:" << reply->errorString();
-        Q_EMIT networkError();
+        setError(PendingWeatherForecast::NetworkError, reply->errorString());
+        Q_EMIT q->finished();
         return;
     }
 
@@ -175,7 +150,7 @@ void PendingWeatherForecastPrivate::parseOneElement(const QJsonObject &obj, std:
     symbolCode = symbolCode.split(QLatin1Char('_'))[0]; // trim _[day/night] from end -
                                                         // https://api.met.no/weatherapi/weathericon/2.0/legends
     HourlyWeatherForecast hourForecast(QDateTime::fromString(obj.value(QStringLiteral("time")).toString(), Qt::ISODate));
-    hourForecast.setNeutralWeatherIcon(self()->resolveAPIWeatherDesc(symbolCode + QStringLiteral("_neutral")).icon);
+    hourForecast.setNeutralWeatherIcon(KWeatherCorePrivate::resolveAPIWeatherDesc(symbolCode + QStringLiteral("_neutral")).icon);
     hourForecast.setTemperature(instant[QStringLiteral("air_temperature")].toDouble());
     hourForecast.setPressure(instant[QStringLiteral("air_pressure_at_sea_level")].toDouble());
     hourForecast.setWindDirection(getWindDeg(instant[QStringLiteral("wind_from_direction")].toDouble()));
@@ -188,30 +163,28 @@ void PendingWeatherForecastPrivate::parseOneElement(const QJsonObject &obj, std:
     hourlyForecast.push_back(std::move(hourForecast));
 }
 
+bool PendingWeatherForecastPrivate::isDayTime(const QDateTime &dt) const
+{
+    const auto sunrise = QDateTime(dt.date(), KHolidays::SunRiseSet::utcSunrise(dt.date(), forecast.latitude(), forecast.longitude()), Qt::UTC);
+    auto sunset = QDateTime(dt.date(), KHolidays::SunRiseSet::utcSunset(dt.date(), forecast.latitude(), forecast.longitude()), Qt::UTC);
+    if (sunset < sunrise) {
+        sunset = sunset.addDays(1);
+    }
+    // 30 min threshold
+    return sunrise.addSecs(-1800) <= dt && sunset.addSecs(1800) >= dt;
+}
+
 void PendingWeatherForecastPrivate::applySunriseToForecast()
 {
     // ************* Lambda *************** //
-    auto isDayTime = [](const QDateTime &date, const std::vector<Sunrise> &sunrise) {
-        for (auto &sr : sunrise) {
-            // if on the same day
-            if (sr.sunRise().date().daysTo(date.date()) == 0 && sr.sunRise().date().day() == date.date().day()) {
-                // 30 min threshold
-                return sr.sunRise().addSecs(-1800) <= date && sr.sunSet().addSecs(1800) >= date;
-            }
-        }
-
-        // not found
-        return date.time().hour() >= 6 && date.time().hour() <= 18;
-    };
-
     auto getSymbolCodeDescription = [](bool isDay, const QString &symbolCode) {
-        return isDay ? self()->resolveAPIWeatherDesc(symbolCode + QStringLiteral("_day")).desc
-                     : self()->resolveAPIWeatherDesc(symbolCode + QStringLiteral("_night")).desc;
+        return isDay ? KWeatherCorePrivate::resolveAPIWeatherDesc(symbolCode + QStringLiteral("_day")).desc
+                     : KWeatherCorePrivate::resolveAPIWeatherDesc(symbolCode + QStringLiteral("_night")).desc;
     };
 
     auto getSymbolCodeIcon = [](bool isDay, const QString &symbolCode) {
-        return isDay ? self()->resolveAPIWeatherDesc(symbolCode + QStringLiteral("_day")).icon
-                     : self()->resolveAPIWeatherDesc(symbolCode + QStringLiteral("_night")).icon;
+        return isDay ? KWeatherCorePrivate::resolveAPIWeatherDesc(symbolCode + QStringLiteral("_day")).icon
+                     : KWeatherCorePrivate::resolveAPIWeatherDesc(symbolCode + QStringLiteral("_night")).icon;
     };
 
     // ******* code ******** //
@@ -219,17 +192,17 @@ void PendingWeatherForecastPrivate::applySunriseToForecast()
         hourForecast.setDate(hourForecast.date().toTimeZone(QTimeZone(m_timezone.toUtf8())));
 
         bool isDay;
-        isDay = isDayTime(hourForecast.date(), m_sunriseSource->value());
+        isDay = isDayTime(hourForecast.date());
         hourForecast.setWeatherIcon(getSymbolCodeIcon(isDay, hourForecast.symbolCode())); // set day/night icon
         hourForecast.setWeatherDescription(getSymbolCodeDescription(isDay, hourForecast.symbolCode()));
         forecast += std::move(hourForecast);
     }
     forecast.setSunriseForecast(m_sunriseSource->value());
-    Q_EMIT finished();
+    Q_EMIT q->finished();
 
     // save to cache
 
-    QFile file(self()->getCacheDirectory(m_latitude, m_longitude).path() + QStringLiteral("/cache.json"));
+    QFile file(KWeatherCorePrivate::getCacheDirectory(forecast.latitude(), forecast.longitude()).path() + QStringLiteral("/cache.json"));
 
     if (file.open(QIODevice::WriteOnly)) {
         file.write(QJsonDocument(forecast.toJson()).toJson(QJsonDocument::Compact));
@@ -238,21 +211,71 @@ void PendingWeatherForecastPrivate::applySunriseToForecast()
     }
 }
 
-PendingWeatherForecast::PendingWeatherForecast(double latitude, double longitude, const QUrl &url, const QString &timezone, const std::vector<Sunrise> &sunrise)
-    : d(new PendingWeatherForecastPrivate(latitude, longitude, timezone, url, sunrise, this))
+PendingWeatherForecast::PendingWeatherForecast(double latitude,
+                                               double longitude,
+                                               const QString &timezone,
+                                               const std::vector<Sunrise> &sunrise,
+                                               QNetworkAccessManager *nam,
+                                               QObject *parent)
+    : Reply(new PendingWeatherForecastPrivate(this), parent)
 {
+    Q_D(PendingWeatherForecast);
+    d->m_manager = nam;
+    connect(this, &PendingWeatherForecast::finished, this, [this] {
+        Q_D(PendingWeatherForecast);
+        d->isFinished = true;
+    });
+
+    // query weather api
+    QUrl url(QStringLiteral("https://api.met.no/weatherapi/locationforecast/2.0/complete"));
+    QUrlQuery query;
+    query.addQueryItem(QStringLiteral("lat"), KWeatherCorePrivate::toFixedString(latitude));
+    query.addQueryItem(QStringLiteral("lon"), KWeatherCorePrivate::toFixedString(longitude));
+    url.setQuery(query);
+    QNetworkRequest req(url);
+    req.setAttribute(QNetworkRequest::RedirectPolicyAttribute, QNetworkRequest::NoLessSafeRedirectPolicy);
+
+    // see §Identification on https://api.met.no/conditions_service.html
+    req.setHeader(QNetworkRequest::UserAgentHeader, QStringLiteral("KWeatherCore/" KWEATHERCORE_VERSION_STRING " kde-frameworks-devel@kde.org"));
+    auto reply = d->m_manager->get(req);
+    connect(reply, &QNetworkReply::finished, this, [reply, this]() {
+        Q_D(PendingWeatherForecast);
+        d->parseWeatherForecastResults(reply);
+    });
+
+    d->forecast.setCoordinate(latitude, longitude);
+
+    d->m_sunriseSource = new SunriseSource(latitude, longitude, d->m_timezone, sunrise, this);
+    if (timezone.isEmpty()) {
+        d->hasTimezone = false;
+        d->getTimezone(latitude, longitude);
+    } else {
+        d->hasTimezone = true;
+        d->forecast.setTimezone(timezone);
+        d->m_timezone = timezone;
+        d->getSunrise();
+    }
 }
-PendingWeatherForecast::PendingWeatherForecast(WeatherForecast data)
-    : d(new PendingWeatherForecastPrivate(data))
+PendingWeatherForecast::PendingWeatherForecast(WeatherForecast data, QObject *parent)
+    : Reply(new PendingWeatherForecastPrivate(this), parent)
 {
+    Q_D(PendingWeatherForecast);
+    d->forecast = data;
+    d->isFinished = true;
+    QMetaObject::invokeMethod(this, &PendingWeatherForecast::finished, Qt::QueuedConnection);
 }
+
+PendingWeatherForecast::~PendingWeatherForecast() = default;
+
 bool PendingWeatherForecast::isFinished() const
 {
+    Q_D(const PendingWeatherForecast);
     return d->isFinished;
 }
 
 WeatherForecast PendingWeatherForecast::value() const
 {
+    Q_D(const PendingWeatherForecast);
     return d->forecast;
 }
 }
