@@ -5,9 +5,11 @@
  * SPDX-License-Identifier: LGPL-2.0-or-later
  */
 #pragma once
+
+#include "reply.h"
 #include "weatherforecast.h"
-#include <QObject>
-#include <kweathercore/kweathercore_export.h>
+
+class QNetworkAccessManager;
 
 namespace KWeatherCore
 {
@@ -20,10 +22,12 @@ class PendingWeatherForecastPrivate;
  *
  * @author Han Young <hanyoung@protonmail.com>
  */
-class KWEATHERCORE_EXPORT PendingWeatherForecast : public QObject
+class KWEATHERCORE_EXPORT PendingWeatherForecast : public Reply
 {
     Q_OBJECT
 public:
+    ~PendingWeatherForecast();
+
     /**
      * value pointer to the shared weather data
      * the pointer is nullptr until finished() raised
@@ -32,30 +36,19 @@ public:
     WeatherForecast value() const;
     /**
      * isFinished if the call has finished
-     * @return
+     * @deprecated No longer needed, finished() is emitted in all cases now.
      */
-    bool isFinished() const;
-
-Q_SIGNALS:
-    /**
-     * signals the call has finished
-     */
-    void finished();
-    /**
-     * indicate there is a network error
-     */
-    void networkError();
-
-protected:
-    friend class WeatherForecastSourcePrivate;
-    explicit PendingWeatherForecast(double latitude,
-                                    double longitude,
-                                    const QUrl &url,
-                                    const QString &timezone = QString(),
-                                    const std::vector<Sunrise> &sunrise = std::vector<Sunrise>());
-    explicit PendingWeatherForecast(WeatherForecast data);
+    [[deprecated("no longer needed")]] bool isFinished() const;
 
 private:
-    PendingWeatherForecastPrivate *d = nullptr;
+    friend class WeatherForecastSource;
+    explicit PendingWeatherForecast(double latitude,
+                                    double longitude,
+                                    const QString &timezone,
+                                    const std::vector<Sunrise> &sunrise,
+                                    QNetworkAccessManager *nam,
+                                    QObject *parent = nullptr);
+    explicit PendingWeatherForecast(WeatherForecast data, QObject *parent = nullptr);
+    Q_DECLARE_PRIVATE(PendingWeatherForecast)
 };
 }
