@@ -1,44 +1,33 @@
 #pragma once
+#include "reply_p.h"
 #include "weatherforecast.h"
-#include <QNetworkAccessManager>
-#include <QObject>
+
 class QNetworkReply;
+class QNetworkAccessManager;
 namespace KWeatherCore
 {
-class WeatherForecastSource;
 class SunriseSource;
 class PendingWeatherForecast;
-class PendingWeatherForecastPrivate : public QObject
+class PendingWeatherForecastPrivate : public ReplyPrivate
 {
-    Q_OBJECT
 public:
-    PendingWeatherForecastPrivate(double latitude,
-                                  double longitude,
-                                  const QString &timezone,
-                                  const QUrl &url,
-                                  const std::vector<Sunrise> &sunrise,
-                                  PendingWeatherForecast *parent = nullptr);
-    PendingWeatherForecastPrivate(WeatherForecast data);
-    WeatherForecast forecast;
-    bool isFinished = false;
+    PendingWeatherForecastPrivate(PendingWeatherForecast *qq);
 
-Q_SIGNALS:
-    void networkError();
-    void finished();
-private Q_SLOTS:
     void parseWeatherForecastResults(QNetworkReply *ret);
     void parseSunriseResults();
     void parseTimezoneResult(const QString &timezone);
 
-private:
     void parseOneElement(const QJsonObject &obj, std::vector<HourlyWeatherForecast> &hourlyForecast);
     void getTimezone(double latitude, double longitude);
     void getSunrise();
+    bool isDayTime(const QDateTime &dt) const;
     void applySunriseToForecast();
 
+    WeatherForecast forecast;
+    PendingWeatherForecast *q = nullptr;
+    bool isFinished = false;
     bool hasTimezone = false;
     bool hasSunrise = false;
-    double m_latitude, m_longitude;
     QString m_timezone;
 
     std::vector<HourlyWeatherForecast> hourlyForecast; // tmp hourly vector
@@ -46,6 +35,6 @@ private:
     SunriseSource *m_sunriseSource = nullptr;
 
     QDateTime m_expiresTime;
-    QNetworkAccessManager m_manager;
+    QNetworkAccessManager *m_manager = nullptr;
 };
 }
