@@ -4,37 +4,38 @@
  *
  * SPDX-License-Identifier: LGPL-2.0-or-later
  */
+
 #include "weatherforecastsource.h"
-#include "geotimezone.h"
 #include "kweathercore_p.h"
-#include "pendingweatherforecast_p.h"
+#include "locationqueryresult.h"
 #include "weatherforecast.h"
-#include <QCoreApplication>
-#include <QDir>
+
 #include <QFile>
 #include <QJsonDocument>
-#include <QNetworkReply>
+#include <QNetworkAccessManager>
 #include <QStandardPaths>
-#include <QUrlQuery>
+
 #include <algorithm>
+
 namespace KWeatherCore
 {
-class WeatherForecastSourcePrivate : public QObject
+class WeatherForecastSourcePrivate
 {
-    Q_OBJECT
 public:
-    WeatherForecastSourcePrivate(QObject *parent = nullptr);
-    PendingWeatherForecast *requestData(double latitude, double longitude);
-
-private:
+    QNetworkAccessManager *m_nam = nullptr;
 };
-WeatherForecastSourcePrivate::WeatherForecastSourcePrivate(QObject *parent)
+
+WeatherForecastSource::WeatherForecastSource(QObject *parent)
     : QObject(parent)
+    , d(new WeatherForecastSourcePrivate)
 {
 }
-PendingWeatherForecast *WeatherForecastSourcePrivate::requestData(double latitude, double longitude)
+
+WeatherForecastSource::~WeatherForecastSource() = default;
+
+PendingWeatherForecast *WeatherForecastSource::requestData(double latitude, double longitude)
 {
-    QFile cache(self()->getCacheDirectory(latitude, longitude).path() + QStringLiteral("/cache.json"));
+    QFile cache(KWeatherCorePrivate::getCacheDirectory(latitude, longitude).path() + QStringLiteral("/cache.json"));
     std::vector<Sunrise> sunriseCache;
     QString timezone;
     // valid cache
@@ -60,28 +61,32 @@ PendingWeatherForecast *WeatherForecastSourcePrivate::requestData(double latitud
         }
     }
 
-    // query weather api
-    QUrl url(QStringLiteral("https://api.met.no/weatherapi/locationforecast/2.0/complete"));
-    QUrlQuery query;
-    query.addQueryItem(QStringLiteral("lat"), self()->toFixedString(latitude));
-    query.addQueryItem(QStringLiteral("lon"), self()->toFixedString(longitude));
+    if (!d->m_nam) {
+        d->m_nam = new QNetworkAccessManager(this);
+        d->m_nam->setRedirectPolicy(QNetworkRequest::NoLessSafeRedirectPolicy);
+        d->m_nam->setStrictTransportSecurityEnabled(true);
+        d->m_nam->enableStrictTransportSecurityStore(true,
+                                                     QStandardPaths::writableLocation(QStandardPaths::GenericCacheLocation)
+                                                         + QLatin1String("/org.kde.kweathercore/hsts/"));
+    }
 
-    url.setQuery(query);
+    return new PendingWeatherForecast(latitude, longitude, timezone, sunriseCache, d->m_nam);
+}
 
-    return new PendingWeatherForecast(latitude, longitude, url, timezone, sunriseCache);
-}
-WeatherForecastSource::WeatherForecastSource(QObject *parent)
-    : QObject(parent)
-    , d(new WeatherForecastSourcePrivate(this))
-{
-}
-PendingWeatherForecast *WeatherForecastSource::requestData(double latitude, double longitude)
-{
-    return d->requestData(latitude, longitude);
-}
 PendingWeatherForecast *WeatherForecastSource::requestData(const KWeatherCore::LocationQueryResult &result)
 {
     return requestData(result.latitude(), result.longitude());
 }
+
+void WeatherForecastSource::setNetworkAccessManager(QNetworkAccessManager *nam)
+{
+    if (d->m_nam == nam) {
+        return;
+    }
+
+    if (d->m_nam->parent() == this) {
+        delete d->m_nam;
+    }
+    d->m_nam = nam;
+}
 }
-#include "weatherforecastsource.moc"
